==> chaosmesh-model-5.2.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NetworkChaosSpecBuilder extends NetworkChaosSpecFluentImpl<NetworkChaosSpecBuilder> implements VisitableBuilder<NetworkChaosSpec,NetworkChaosSpecBuilder> {

    NetworkChaosSpecFluent<?> fluent;
    Boolean validationEnabled;

    public NetworkChaosSpecBuilder() {
        this(true);
    }

    public NetworkChaosSpecBuilder(Boolean validationEnabled) {
        this(new NetworkChaosSpec(), validationEnabled);
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new NetworkChaosSpec(), validationEnabled);
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,NetworkChaosSpec instance) {
        this(fluent, instance, true);
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,NetworkChaosSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAction(instance.getAction()); 
        fluent.withBandwidth(instance.getBandwidth()); 
        fluent.withCorrupt(instance.getCorrupt()); 
        fluent.withDelay(instance.getDelay()); 
        fluent.withDirection(instance.getDirection()); 
        fluent.withDuplicate(instance.getDuplicate()); 
        fluent.withDuration(instance.getDuration()); 
        fluent.withExternalTargets(instance.getExternalTargets()); 
        fluent.withLoss(instance.getLoss()); 
        fluent.withMode(instance.getMode()); 
        fluent.withScheduler(instance.getScheduler()); 
        fluent.withSelector(instance.getSelector()); 
        fluent.withTarget(instance.getTarget()); 
        fluent.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpec instance) {
        this(instance,true);
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAction(instance.getAction()); 
        this.withBandwidth(instance.getBandwidth()); 
        this.withCorrupt(instance.getCorrupt()); 
        this.withDelay(instance.getDelay()); 
        this.withDirection(instance.getDirection()); 
        this.withDuplicate(instance.getDuplicate()); 
        this.withDuration(instance.getDuration()); 
        this.withExternalTargets(instance.getExternalTargets()); 
        this.withLoss(instance.getLoss()); 
        this.withMode(instance.getMode()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withTarget(instance.getTarget()); 
        this.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableNetworkChaosSpec build() {
        EditableNetworkChaosSpec buildable = new EditableNetworkChaosSpec(fluent.getAction(),fluent.getBandwidth(),fluent.getCorrupt(),fluent.getDelay(),fluent.getDirection(),fluent.getDuplicate(),fluent.getDuration(),fluent.getExternalTargets(),fluent.getLoss(),fluent.getMode(),fluent.getScheduler(),fluent.getSelector(),fluent.getTarget(),fluent.getValue());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        NetworkChaosSpecBuilder that = (NetworkChaosSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NetworkChaosSpecBuilder extends NetworkChaosSpecFluentImpl<NetworkChaosSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<NetworkChaosSpec,NetworkChaosSpecBuilder> {

    NetworkChaosSpecFluent<?> fluent;
    Boolean validationEnabled;

    public NetworkChaosSpecBuilder() {
        this(true);
    }

    public NetworkChaosSpecBuilder(Boolean validationEnabled) {
        this(new NetworkChaosSpec(), validationEnabled);
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new NetworkChaosSpec(), validationEnabled);
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,NetworkChaosSpec instance) {
        this(fluent, instance, true);
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,NetworkChaosSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAction(instance.getAction()); 
        fluent.withBandwidth(instance.getBandwidth()); 
        fluent.withCorrupt(instance.getCorrupt()); 
        fluent.withDelay(instance.getDelay()); 
        fluent.withDirection(instance.getDirection()); 
        fluent.withDuplicate(instance.getDuplicate()); 
        fluent.withDuration(instance.getDuration()); 
        fluent.withExternalTargets(instance.getExternalTargets()); 
        fluent.withLoss(instance.getLoss()); 
        fluent.withMode(instance.getMode()); 
        fluent.withScheduler(instance.getScheduler()); 
        fluent.withSelector(instance.getSelector()); 
        fluent.withTarget(instance.getTarget()); 
        fluent.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpec instance) {
        this(instance,true);
    }

    public NetworkChaosSpecBuilder(NetworkChaosSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAction(instance.getAction()); 
        this.withBandwidth(instance.getBandwidth()); 
        this.withCorrupt(instance.getCorrupt()); 
        this.withDelay(instance.getDelay()); 
        this.withDirection(instance.getDirection()); 
        this.withDuplicate(instance.getDuplicate()); 
        this.withDuration(instance.getDuration()); 
        this.withExternalTargets(instance.getExternalTargets()); 
        this.withLoss(instance.getLoss()); 
        this.withMode(instance.getMode()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withTarget(instance.getTarget()); 
        this.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableNetworkChaosSpec build() {
        EditableNetworkChaosSpec buildable = new EditableNetworkChaosSpec(fluent.getAction(),fluent.getBandwidth(),fluent.getCorrupt(),fluent.getDelay(),fluent.getDirection(),fluent.getDuplicate(),fluent.getDuration(),fluent.getExternalTargets(),fluent.getLoss(),fluent.getMode(),fluent.getScheduler(),fluent.getSelector(),fluent.getTarget(),fluent.getValue());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        NetworkChaosSpecBuilder that = (NetworkChaosSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
